@@ -5,6 +5,7 @@
 import matplotlib.pyplot as plt
 import matplotlib.testing.compare
 import numpy as np
+import pytest
 
 from pde.tools.plotting import add_scaled_colorbar, plot_on_axes, plot_on_figure
 
@@ -35,6 +36,7 @@ def test_plot_on_figure(tmp_path):
     assert path.stat().st_size > 0
 
 
+@pytest.mark.interactive
 def test_plot_colorbar(tmp_path):
     """test the plot_on_axes decorator"""
     data = np.random.randn(3, 3)
